@@ -17,12 +17,8 @@ extern crate core;
 #[macro_use]
 extern crate alloc;
 
-#[cfg_attr(feature = "std", macro_use)]
-extern crate tracing;
-
-#[cfg(not(feature = "std"))]
 #[macro_use]
-extern crate ockam_executor;
+extern crate tracing;
 
 #[cfg(not(feature = "std"))]
 pub use ockam_executor::tokio;
