@@ -39,6 +39,9 @@ where
         // This future encodes the main processor run loop logic
         let run_loop = async {
             loop {
+                // protect against accidental async executor deadlock
+                crate::tokio::task::yield_now().await;
+
                 let should_continue = processor.process(&mut ctx).await?;
                 if !should_continue {
                     break;
